import lodash from 'lodash'
import { interact, replaceApiParams } from '../../utils'
import apis from '../../config/api'

export default {
  namespaced: true,
  state: {
    propagandas: {},
    detail: {}
  },
  mutations: {
    updateList (state, payload) {
      state.propagandas = payload
    },
    updateDetail (state, payload) {
      state.detail = payload
    }
  },
  actions: {
    setDetailNull ({ commit }) {
      commit('updateDetail', {})
    },
    getPropagandas ({ commit }, payload) {
      return new Promise((resolve, reject) => {
        const api = lodash.get(apis, 'propaganda.list')
        interact(api, payload).then((data) => {
          commit('updateList', data)
          resolve(data)
        }).catch(({ message }) => {
          if (typeof message === 'string') {
            reject(message)
          }
        })
      })
    },
    getDetail ({ commit }, payload) {
      return new Promise((resolve, reject) => {
        const api = replaceApiParams(lodash.get(apis, 'propaganda.detail'), payload)
        interact(api).then((data) => {
          commit('updateDetail', data)
          resolve(data)
        }).catch(({ message }) => {
          if (typeof message === 'string') {
            reject(message)
          }
        })
      })
    },
    addPropaganda (_, payload) {
      return new Promise((resolve, reject) => {
        const api = lodash.get(apis, 'propaganda.add')
        interact(api, payload).then((data) => {
          resolve(data)
        }).catch(({ message }) => {
          if (typeof message === 'string') {
            reject(message)
          }
        })
      })
    },
    editPropaganda (_, payload) {
      return new Promise((resolve, reject) => {
        const api = lodash.get(apis, 'propaganda.update')
        interact(api, payload).then((data) => {
          resolve(data)
        }).catch(({ message }) => {
          if (typeof message === 'string') {
            reject(message)
          }
        })
      })
    },
    deletePropaganda (_, payload) {
      return new Promise((resolve, reject) => {
        const api = replaceApiParams(lodash.get(apis, 'propaganda.delete'), payload)
        interact(api).then(() => {
          resolve()
        }).catch(() => {
          reject()
        })
      })
    }
  }
}